# EvidenceData

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**custom_fields** | [**dict(str, AdvanceArg)**](AdvanceArg.md) | This field must have empty json key | [optional] 
**description** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 
**occurred** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 
**tags** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


